The database interface of `Pytroll <https://pytroll.github.io/>`_


.. image:: https://results.pre-commit.ci/badge/github/pytroll/pytroll-db/master.svg
   :target: https://results.pre-commit.ci/latest/github/pytroll/pytroll-db/master
   :alt: pre-commit.ci status


Copyright (C)
    2012, 2014, 2015, 2024

    Martin Raspaud, Pouria Khalaj, Esben S. Nielsen, Adam Dybbroe, Kristian Rune Larsen


Authors
    - Martin Raspaud <martin.raspaud@smhi.se>
    - Pouria Khalaj <pouria.khalaj@smhi.se>
    - Esben S. Nielsen <esn@dmi.dk>
    - Adam Dybbroe <Adam.Dybbroe@smhi.se>
    - Kristian Rune Larsen <krl@dmi.dk>


License
    Consult the `LICENSE` file which is included as a part of this package.


Disclaimer
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details. You should have
    received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
